@@ -21,29 +21,37 @@
 #' \donttest{
 #' # Acquire environmental variables
 #' files <- list.files(path = file.path(system.file(package = "dismo"), "ex"),
-#'                     pattern = "grd", full.names = TRUE)
-#' predictors <- raster::stack(files)
+#'                     pattern = "grd",
+#'                     full.names = TRUE)
+#'
+#' predictors <- terra::rast(files)
 #'
 #' # Prepare presence and background locations
 #' p_coords <- virtualSp$presence
 #' bg_coords <- virtualSp$background
 #'
 #' # Create SWD object
-#' data <- prepareSWD(species = "Virtual species", p = p_coords, a = bg_coords,
-#'                    env = predictors, categorical = "biome")
+#' data <- prepareSWD(species = "Virtual species",
+#'                    p = p_coords,
+#'                    a = bg_coords,
+#'                    env = predictors,
+#'                    categorical = "biome")
 #'
 #' # Train a Maxent model
 #' # The next line checks if Maxent is correctly configured but you don't need
 #' # to run it in your script
-#' if (dismo::maxent(silent = TRUE)) {
-#' model <- train(method = "Maxent", data = data, fc = "l")
+#' model <- train(method = "Maxent",
+#'                data = data,
+#'                fc = "l")
+#'
 #' maxentVarImp(model)
 #' }
-#' }
 maxentVarImp <- function(model) {
 
   if (.get_model_class(model) != "Maxent")
-    stop("'model' must be a SDMmodel object trained using the 'Maxent' method!")
+    cli::cli_abort(c(
+      "!" = "Function available only for {.cls Maxent} models",
+      "x" = "You have supplied a {.cls {class(model@model)}} instead."))
 
   if (inherits(model, "SDMmodel")) {
     x <- model@model@results
@@ -66,14 +74,17 @@ maxentVarImp <- function(model) {
                     "Permutation_importance")
   df <- df[order(-df$Percent_contribution), ]
   row.names(df) <- NULL
-  return(df)
+
+  df
 }
 
 .fetch_var_imp <- function(x) {
   pc <- x[grepl("contribution", rownames(x)), ]
   pi <- x[grepl("permutation.importance", rownames(x)), ]
   variables <- gsub(".contribution", "", names(pc))
-  df <- data.frame(x = variables, y = pc, z = pi, row.names = NULL,
-                   stringsAsFactors = FALSE)
-  return(df)
+
+  data.frame(x = variables,
+             y = pc,
+             z = pi,
+             row.names = NULL)
 }
