@@ -23,26 +23,41 @@
 #' \donttest{
 #' # Acquire environmental variables
 #' files <- list.files(path = file.path(system.file(package = "dismo"), "ex"),
-#'                     pattern = "grd", full.names = TRUE)
-#' predictors <- raster::stack(files)
+#'                     pattern = "grd",
+#'                     full.names = TRUE)
+#'
+#' predictors <- terra::rast(files)
 #'
 #' # Prepare presence and background locations
 #' p_coords <- virtualSp$presence
 #' bg_coords <- virtualSp$background
 #'
 #' # Create SWD object
-#' data <- prepareSWD(species = "Virtual species", p = p_coords, a = bg_coords,
-#'                    env = predictors, categorical = "biome")
+#' data <- prepareSWD(species = "Virtual species",
+#'                    p = p_coords,
+#'                    a = bg_coords,
+#'                    env = predictors,
+#'                    categorical = "biome")
 #' \dontrun{
 #' # The following commands save the output in the working directory
 #' # Save the SWD object as a single csv file
-#' swd2csv(data, "train_data.csv")
+#' swd2csv(data,
+#'         file_name = "train_data.csv")
 #'
 #' # Save the SWD object in two separate csv files
-#' swd2csv(data, c("presence.csv", "absence.csv"))
+#' swd2csv(data,
+#'         file_name = c("presence.csv", "absence.csv"))
 #' }
 #' }
-swd2csv <- function(swd, file_name) {
+swd2csv <- function(swd,
+                    file_name) {
+
+  file_ext <- tools::file_ext(file_name)
+
+  if (sum(file_ext == "") > 0)
+    cli::cli_abort(c(
+      "x" = "Filename must include the extension"
+    ))
 
   if (length(file_name) == 2) {
     df <- cbind(swd@species, swd@coords, swd@data)
