@@ -1,5 +1,5 @@
 test_that("The function is verbose", {
-  expect_message(checkMaxentInstallation(verbose = TRUE))
+  expect_snapshot(checkMaxentInstallation(verbose = TRUE))
 })
 
 test_that("The function output a silent logical", {
