@@ -1,7 +1,7 @@
 x <- SDMtune:::t
 
 test_that("The function raises error", {
-  expect_error(corVar(x@data), "\"bg\" must be an SWD object!")
+  expect_snapshot_error(corVar(x@data))
 })
 
 test_that("The function creates the correct output", {
@@ -17,7 +17,7 @@ test_that("The function creates the correct output", {
   expect_true(cm[1, 3] != 1)
   cm1 <- corVar(x, remove_diagonal = FALSE)
   expect_equal(cm1[1, 3], 1)
-  # The first 2 columns are not factors
-  expect_false(is.factor(cm[, 1]))
-  expect_false(is.factor(cm[, 2]))
+  # The first 2 columns are factors
+  expect_true(is.factor(cm[, 1]))
+  expect_true(is.factor(cm[, 2]))
 })
